@@ -23,7 +23,7 @@ hinge.test <- function(formula, cov.interest, family=c("binomial","gaussian"), d
 
     # save rng state before set.seed in order to restore before exiting this function
     save.seed <- try(get(".Random.seed", .GlobalEnv), silent=TRUE) 
-    if (class(save.seed)=="try-error") {set.seed(1); save.seed <- get(".Random.seed", .GlobalEnv) }                        
+    if (inherits(save.seed,"try-error")) {set.seed(1); save.seed <- get(".Random.seed", .GlobalEnv) }                        
     set.seed(1)    
     
     # parametric bootstrap and fast double bootstrap
